QT_TRANSLATE_NOOP("core","Columbus/Visiontac V900 files (.csv)")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Comma separated values")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Data Logger iBlue747 csv")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Data Logger iBlue757 csv")
QT_TRANSLATE_NOOP("core","Set waypoint name to source filename")
QT_TRANSLATE_NOOP("core","Time-frame (in seconds)")
QT_TRANSLATE_NOOP("core","Locate waypoint for tagging by this name")
QT_TRANSLATE_NOOP("core","!OVERWRITE! the original file. Default=N")
QT_TRANSLATE_NOOP("core","Image Offset Time (+HH:MM or -HH:MM)")
QT_TRANSLATE_NOOP("core","Embedded Exif-GPS data (.jpg)")
QT_TRANSLATE_NOOP("core","Source for name field in .dbf")
QT_TRANSLATE_NOOP("core","Source for URL field in .dbf")
QT_TRANSLATE_NOOP("core","ESRI shapefile")
QT_TRANSLATE_NOOP("core","(integer sec or 'auto') Barograph to GPS time diff")
QT_TRANSLATE_NOOP("core","Engine Noise (ENL; default=1)")
QT_TRANSLATE_NOOP("core","True Airspeed (TAS; default=1)")
QT_TRANSLATE_NOOP("core","Total Energy Vario (VAT; default=1)")
QT_TRANSLATE_NOOP("core","Outside Air Temperature (OAT; default=1)")
QT_TRANSLATE_NOOP("core","True Track (TRT; default=0)")
QT_TRANSLATE_NOOP("core","Ground Speed (GSP; default=1)")
QT_TRANSLATE_NOOP("core","Fix Accuracy (FXA; default=1)")
QT_TRANSLATE_NOOP("core","# Of Sats (SIU; default=0)")
QT_TRANSLATE_NOOP("core","Z Acceleration (ACZ; default=1)")
QT_TRANSLATE_NOOP("core","G Force? (GFO; default=0)")
QT_TRANSLATE_NOOP("core","FAI/IGC Flight Recorder Data Format")
QT_TRANSLATE_NOOP("core","Read all points even if latitude or longitude is missing")
QT_TRANSLATE_NOOP("core","Attempt to recovery data from corrupt file")
QT_TRANSLATE_NOOP("core","Flexible and Interoperable Data Transfer (FIT) Activity file")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Garmin 301 Custom position and heartrate")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Garmin G1000 datalog input filter file")
QT_TRANSLATE_NOOP("core","Default category on output (1..16)")
QT_TRANSLATE_NOOP("core","Bitmap of categories")
QT_TRANSLATE_NOOP("core","Version of gdb file to generate (1..3)")
QT_TRANSLATE_NOOP("core","Drop route points that do not have an equivalent waypoint (hidden points)")
QT_TRANSLATE_NOOP("core","Don't create waypoints for non-user points")
QT_TRANSLATE_NOOP("core","Include major turn points (with description) from calculated route")
QT_TRANSLATE_NOOP("core","Garmin MapSource - gdb")
QT_TRANSLATE_NOOP("core","Read/Write date format (i.e. yyyy/mm/dd)")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Distance unit [m=metric, s=statute]")
QT_TRANSLATE_NOOP("core","Write position using this grid.")
QT_TRANSLATE_NOOP("core","Precision of coordinates")
QT_TRANSLATE_NOOP("core","Temperature unit [c=Celsius, f=Fahrenheit]")
QT_TRANSLATE_NOOP("core","Read/Write time format (i.e. HH:mm:ss xx)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Garmin MapSource - txt (tab delimited)")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Garmin POI database")
QT_TRANSLATE_NOOP("core","Enable alerts on speed or proximity distance")
QT_TRANSLATE_NOOP("core","Use specified bitmap on output")
QT_TRANSLATE_NOOP("core","Default category on output")
QT_TRANSLATE_NOOP("core","Don't show gpi bitmap on device")
QT_TRANSLATE_NOOP("core","Write description to address field")
QT_TRANSLATE_NOOP("core","Write notes to address field")
QT_TRANSLATE_NOOP("core","Write position to address field")
QT_TRANSLATE_NOOP("core","Default proximity")
QT_TRANSLATE_NOOP("core","After output job done sleep n second(s)")
QT_TRANSLATE_NOOP("core","Default speed")
QT_TRANSLATE_NOOP("core","Create unique waypoint names (default = yes)")
QT_TRANSLATE_NOOP("core","Units used for names with @speed ('s'tatute or 'm'etric)")
QT_TRANSLATE_NOOP("core","codec to use for writing strings")
QT_TRANSLATE_NOOP("core","language code to use for reading dual language files")
QT_TRANSLATE_NOOP("core","Garmin Points of Interest (.gpi)")
QT_TRANSLATE_NOOP("core","Length of generated shortnames")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","Default icon name")
QT_TRANSLATE_NOOP("core","Return current position as a waypoint")
QT_TRANSLATE_NOOP("core","Command unit to power itself down")
QT_TRANSLATE_NOOP("core","Erase existing courses when writing new ones")
QT_TRANSLATE_NOOP("core","Sync GPS time to computer time")
QT_TRANSLATE_NOOP("core","Category number to use for written waypoints")
QT_TRANSLATE_NOOP("core","Bitmap of categories")
QT_TRANSLATE_NOOP("core","Speed in bits per second of serial port (baud=9600)")
QT_TRANSLATE_NOOP("core","override codec to use for device")
QT_TRANSLATE_NOOP("core","Garmin serial/USB protocol")
QT_TRANSLATE_NOOP("core","Write course rather than history, default yes")
QT_TRANSLATE_NOOP("core","Sport: Biking (deflt), Running, MultiSport, Other")
QT_TRANSLATE_NOOP("core","Garmin Training Center (.tcx/.crs/.hst/.xml)")
QT_TRANSLATE_NOOP("core","Default icon name")
QT_TRANSLATE_NOOP("core","Geocaching.com .loc")
QT_TRANSLATE_NOOP("core","Compact Output. Default is off.")
QT_TRANSLATE_NOOP("core","GeoJson")
QT_TRANSLATE_NOOP("core","Erase device data after download")
QT_TRANSLATE_NOOP("core","Only erase device data, do not download anything")
QT_TRANSLATE_NOOP("core","GlobalSat DG-100/BT-335 Download")
QT_TRANSLATE_NOOP("core","Erase device data after download")
QT_TRANSLATE_NOOP("core","Only erase device data, do not download anything")
QT_TRANSLATE_NOOP("core","GlobalSat DG-200 Download")
QT_TRANSLATE_NOOP("core","list tracks")
QT_TRANSLATE_NOOP("core","Dump raw data to this file")
QT_TRANSLATE_NOOP("core","Dump raw data to this file")
QT_TRANSLATE_NOOP("core","Time zone ID")
QT_TRANSLATE_NOOP("core","GlobalSat GH625XT GPS training watch")
QT_TRANSLATE_NOOP("core","Default icon name")
QT_TRANSLATE_NOOP("core","Export linestrings for tracks and routes")
QT_TRANSLATE_NOOP("core","Export placemarks for tracks and routes")
QT_TRANSLATE_NOOP("core","Width of lines, in pixels")
QT_TRANSLATE_NOOP("core","Line color, specified in hex AABBGGRR")
QT_TRANSLATE_NOOP("core","Altitudes are absolute and not clamped to ground")
QT_TRANSLATE_NOOP("core","Draw extrusion line from trackpoint to ground")
QT_TRANSLATE_NOOP("core","Write KML track (default = 0)")
QT_TRANSLATE_NOOP("core","Include extended data for trackpoints (default = 1)")
QT_TRANSLATE_NOOP("core","Indicate direction of travel in track icons (default = 0)")
QT_TRANSLATE_NOOP("core","Units used when writing comments ('s'tatute, 'm'etric,' 'n'autical, 'a'viation)")
QT_TRANSLATE_NOOP("core","Display labels on track and routepoints  (default = 1)")
QT_TRANSLATE_NOOP("core","Retain at most this number of position points  (0 = unlimited)")
QT_TRANSLATE_NOOP("core","Rotate colors for tracks and routes (default automatic)")
QT_TRANSLATE_NOOP("core","Precision of coordinates, number of decimals")
QT_TRANSLATE_NOOP("core","Google Earth (Keyhole) Markup Language")
QT_TRANSLATE_NOOP("core","Google Takeout Location History")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","GPS Tracking Key Pro text")
QT_TRANSLATE_NOOP("core","GPS TrackMaker")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","GPSBabel arc filter file")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","GpsDrive Format")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","GpsDrive Format for Tracks")
QT_TRANSLATE_NOOP("core","Length of generated shortnames")
QT_TRANSLATE_NOOP("core","No whitespace in generated shortnames")
QT_TRANSLATE_NOOP("core","Create waypoints from geocache log entries")
QT_TRANSLATE_NOOP("core","Base URL for link tag in output")
QT_TRANSLATE_NOOP("core","Target GPX version for output")
QT_TRANSLATE_NOOP("core","Add info (depth) as Humminbird extension")
QT_TRANSLATE_NOOP("core","Add info (depth) as Garmin extension")
QT_TRANSLATE_NOOP("core","Precision of elevations, number of decimals")
QT_TRANSLATE_NOOP("core","GPX XML")
QT_TRANSLATE_NOOP("core","MTK compatible CSV output file")
QT_TRANSLATE_NOOP("core","Holux M-241 (MTK based) Binary File Format")
QT_TRANSLATE_NOOP("core","Erase device data after download")
QT_TRANSLATE_NOOP("core","Only erase device data, do not download anything")
QT_TRANSLATE_NOOP("core","Enable logging after download")
QT_TRANSLATE_NOOP("core","MTK compatible CSV output file")
QT_TRANSLATE_NOOP("core","Size of blocks in KB to request from device")
QT_TRANSLATE_NOOP("core","Holux M-241 (MTK based) download")
QT_TRANSLATE_NOOP("core","Path to HTML style sheet")
QT_TRANSLATE_NOOP("core","Encrypt hints using ROT13")
QT_TRANSLATE_NOOP("core","Include groundspeak logs if present")
QT_TRANSLATE_NOOP("core","Degrees output as 'ddd', 'dmm'(default) or 'dms'")
QT_TRANSLATE_NOOP("core","Units for altitude (f)eet or (m)etres")
QT_TRANSLATE_NOOP("core","HTML Output")
QT_TRANSLATE_NOOP("core","Humminbird tracks (.ht)")
QT_TRANSLATE_NOOP("core","Humminbird waypoints and routes (.hwr)")
QT_TRANSLATE_NOOP("core","(USR input) Ignore event marker icons on read")
QT_TRANSLATE_NOOP("core","(USR output) Treat waypoints as icons on write")
QT_TRANSLATE_NOOP("core","(USR output) Merge into one segmented trail")
QT_TRANSLATE_NOOP("core","(USR input) Break segments into separate trails")
QT_TRANSLATE_NOOP("core","(USR output) Write version")
QT_TRANSLATE_NOOP("core","(USR output) Output file title string")
QT_TRANSLATE_NOOP("core","(USR output) Device serial number")
QT_TRANSLATE_NOOP("core","(USR output) Output file content description")
QT_TRANSLATE_NOOP("core","Lowrance USR")
QT_TRANSLATE_NOOP("core","Baud rate used for download")
QT_TRANSLATE_NOOP("core","Dump raw data to this file")
QT_TRANSLATE_NOOP("core","Erase device data after download")
QT_TRANSLATE_NOOP("core","First sector to be read from the device")
QT_TRANSLATE_NOOP("core","Baud rate used to init device (0=autodetect)")
QT_TRANSLATE_NOOP("core","Last sector to be read from the device (-1: smart read everything)")
QT_TRANSLATE_NOOP("core","Disable output (useful with erase)")
QT_TRANSLATE_NOOP("core","Number of sectors to read at once (0=use single sector mode)")
QT_TRANSLATE_NOOP("core","POI for Home Symbol as lat:lng[:alt]")
QT_TRANSLATE_NOOP("core","POI for Car Symbol as lat:lng[:alt]")
QT_TRANSLATE_NOOP("core","POI for Boat Symbol as lat:lng[:alt]")
QT_TRANSLATE_NOOP("core","POI for Heart Symbol as lat:lng[:alt]")
QT_TRANSLATE_NOOP("core","POI for Bar Symbol as lat:lng[:alt]")
QT_TRANSLATE_NOOP("core","Seconds that GPS time tracks UTC (0: best guess)")
QT_TRANSLATE_NOOP("core","GPS week rollover period we're in (-1: best guess)")
QT_TRANSLATE_NOOP("core","MiniHomer, a skyTraq Venus 6 based logger (download tracks, waypoints and get/set POI)")
QT_TRANSLATE_NOOP("core","Garmin Mobile XT ([ATRK]/STRK)")
QT_TRANSLATE_NOOP("core","Track name processing option ([0]-nrm/1-ign)")
QT_TRANSLATE_NOOP("core","Mobile Garmin XT Track files")
QT_TRANSLATE_NOOP("core","MTK compatible CSV output file")
QT_TRANSLATE_NOOP("core","MTK Logger (iBlue 747,...) Binary File Format")
QT_TRANSLATE_NOOP("core","Erase device data after download")
QT_TRANSLATE_NOOP("core","Only erase device data, do not download anything")
QT_TRANSLATE_NOOP("core","Enable logging after download")
QT_TRANSLATE_NOOP("core","MTK compatible CSV output file")
QT_TRANSLATE_NOOP("core","Size of blocks in KB to request from device")
QT_TRANSLATE_NOOP("core","MTK Logger (iBlue 747,Qstarz BT-1000,...) download")
QT_TRANSLATE_NOOP("core","Datum (default=NAD27)")
QT_TRANSLATE_NOOP("core","National Geographic Topo .tpg (waypoints)")
QT_TRANSLATE_NOOP("core","National Geographic Topo 2.x .tpo")
QT_TRANSLATE_NOOP("core","National Geographic Topo 3.x/4.x .tpo")
QT_TRANSLATE_NOOP("core","Max length of waypoint name to write")
QT_TRANSLATE_NOOP("core","Read/write GPRMC sentences")
QT_TRANSLATE_NOOP("core","Read/write GPGGA sentences")
QT_TRANSLATE_NOOP("core","Read/write GPVTG sentences")
QT_TRANSLATE_NOOP("core","Read/write GPGSA sentences")
QT_TRANSLATE_NOOP("core","Complete date-free tracks with given date (YYYYMMDD).")
QT_TRANSLATE_NOOP("core","Return current position as a waypoint")
QT_TRANSLATE_NOOP("core","Decimal seconds to pause between groups of strings")
QT_TRANSLATE_NOOP("core","Append realtime positioning data to the output file instead of truncating")
QT_TRANSLATE_NOOP("core","Speed in bits per second of serial port (baud=4800)")
QT_TRANSLATE_NOOP("core","Write tracks for Gisteq Phototracker")
QT_TRANSLATE_NOOP("core","Accept position fixes in gpgga marked invalid")
QT_TRANSLATE_NOOP("core","NMEA 0183 sentences")
QT_TRANSLATE_NOOP("core","Write additional way tag key/value pairs")
QT_TRANSLATE_NOOP("core","Write additional node tag key/value pairs")
QT_TRANSLATE_NOOP("core","Use this value as custom created_by value")
QT_TRANSLATE_NOOP("core","OpenStreetMap data files")
QT_TRANSLATE_NOOP("core","Write all tracks into one file")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Waypoint foreground color")
QT_TRANSLATE_NOOP("core","Waypoint background color")
QT_TRANSLATE_NOOP("core","Proximity distance")
QT_TRANSLATE_NOOP("core","Unit used in altitude values")
QT_TRANSLATE_NOOP("core","Unit used in proximity values")
QT_TRANSLATE_NOOP("core","codec to use for reading and writing strings (default windows-1252)")
QT_TRANSLATE_NOOP("core","OziExplorer")
QT_TRANSLATE_NOOP("core","Qstarz BL-1000")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","See You flight analysis data")
QT_TRANSLATE_NOOP("core","Erase device data after download")
QT_TRANSLATE_NOOP("core","Set location finder target location as lat,lng")
QT_TRANSLATE_NOOP("core","Configure logging parameter as tmin:tmax:dmin:dmax")
QT_TRANSLATE_NOOP("core","Baud rate used for download")
QT_TRANSLATE_NOOP("core","Baud rate used to init device (0=autodetect)")
QT_TRANSLATE_NOOP("core","Number of sectors to read at once (0=use single sector mode)")
QT_TRANSLATE_NOOP("core","First sector to be read from the device")
QT_TRANSLATE_NOOP("core","Last sector to be read from the device (-1: smart read everything)")
QT_TRANSLATE_NOOP("core","Dump raw data to this file")
QT_TRANSLATE_NOOP("core","Disable output (useful with erase)")
QT_TRANSLATE_NOOP("core","Seconds that GPS time tracks UTC (0: best guess)")
QT_TRANSLATE_NOOP("core","GPS week rollover period we're in (-1: best guess)")
QT_TRANSLATE_NOOP("core","SkyTraq Venus based loggers (download)")
QT_TRANSLATE_NOOP("core","First sector to be read from the file")
QT_TRANSLATE_NOOP("core","Last sector to be read from the file (-1: read till empty sector)")
QT_TRANSLATE_NOOP("core","Seconds that GPS time tracks UTC (0: best guess)")
QT_TRANSLATE_NOOP("core","GPS week rollover period we're in (-1: best guess)")
QT_TRANSLATE_NOOP("core","SkyTraq Venus based loggers Binary File Format")
QT_TRANSLATE_NOOP("core","Video position for which exact GPS time is known (hhmmss[.sss], default is 00:00:00,000)")
QT_TRANSLATE_NOOP("core","GPS time at position video_time (hhmmss[.sss], default is first timestamp of track)")
QT_TRANSLATE_NOOP("core","GPS date at position video_time (yyyymmdd, default is first timestamp of track)")
QT_TRANSLATE_NOOP("core","Format for subtitles")
QT_TRANSLATE_NOOP("core","SubRip subtitles for video mapping (.srt)")
QT_TRANSLATE_NOOP("core","Max synthesized shortname length")
QT_TRANSLATE_NOOP("core","Allow whitespace synth. shortnames")
QT_TRANSLATE_NOOP("core","UPPERCASE synth. shortnames")
QT_TRANSLATE_NOOP("core","Make synth. shortnames unique")
QT_TRANSLATE_NOOP("core","Basename prepended to URL on output")
QT_TRANSLATE_NOOP("core","Use shortname instead of description")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Tab delimited fields useful for OpenOffice")
QT_TRANSLATE_NOOP("core","Suppress separator lines between waypoints")
QT_TRANSLATE_NOOP("core","Encrypt hints using ROT13")
QT_TRANSLATE_NOOP("core","Include groundspeak logs if present")
QT_TRANSLATE_NOOP("core","Degrees output as 'ddd', 'dmm'(default) or 'dms'")
QT_TRANSLATE_NOOP("core","Units for altitude (f)eet or (m)etres")
QT_TRANSLATE_NOOP("core","Write each waypoint in a separate file")
QT_TRANSLATE_NOOP("core","Textual Output")
QT_TRANSLATE_NOOP("core","GPS datum (def. WGS 84)")
QT_TRANSLATE_NOOP("core","Write position using this grid.")
QT_TRANSLATE_NOOP("core","Write timestamps with offset x to UTC time")
QT_TRANSLATE_NOOP("core","Write name(s) of format(s) from input session(s)")
QT_TRANSLATE_NOOP("core","Write filename(s) from input session(s)")
QT_TRANSLATE_NOOP("core","Universal csv with field structure in first line")
QT_TRANSLATE_NOOP("core","Encrypt hints using ROT13")
QT_TRANSLATE_NOOP("core","Vcard Output (for iPod)")
